--! insert_book_one()
INSERT INTO Book (title)
  VALUES ('bob');

--! insert_book_zero_or_one()?
INSERT INTO Book (title)
  VALUES ('alice');

--! insert_book_zero_or_more()*
INSERT INTO Book (title)
  VALUES ('carl');

--! insert_stream()#
INSERT INTO Book (title)
  VALUES ('dominic');

